# encoding: UTF-8

require 'sketchup.rb'

module SaveLowVersionSKP
  PLUGIN_NAME = '另存旧版'
  PLUGIN_VERSION = '1.0'
  PLUGIN_AUTHOR = 'liutao'
  PLUGIN_COPYRIGHT = '本插件使用ChatGpt创建,更多插件可前往liutao91.cn下载。'
  PLUGIN_DESCRIPTION = '将文件另存为低版本的Skp文件。'

  # 添加元数据信息
  def self.extension_info
    {
      name: PLUGIN_NAME,
      version: PLUGIN_VERSION,
      description: PLUGIN_DESCRIPTION,
      author: PLUGIN_AUTHOR,
      copyright: PLUGIN_COPYRIGHT
    }
  end

  # 获取支持的SketchUp版本列表
  def self.supported_versions
    {
      'SketchUp 3.0' => Sketchup::Model::VERSION_3,
      'SketchUp 4.0' => Sketchup::Model::VERSION_4,
      'SketchUp 5.0' => Sketchup::Model::VERSION_5,
      'SketchUp 6.0' => Sketchup::Model::VERSION_6,
      'SketchUp 7.0' => Sketchup::Model::VERSION_7,
      'SketchUp 8.0' => Sketchup::Model::VERSION_8,
      'SketchUp 2013' => Sketchup::Model::VERSION_2013,
      'SketchUp 2014' => Sketchup::Model::VERSION_2014,
      'SketchUp 2015' => Sketchup::Model::VERSION_2015,
      'SketchUp 2016' => Sketchup::Model::VERSION_2016,
      'SketchUp 2017' => Sketchup::Model::VERSION_2017,
      'SketchUp 2018' => Sketchup::Model::VERSION_2018,
      'SketchUp 2019' => Sketchup::Model::VERSION_2019,
      'SketchUp 2020' => Sketchup::Model::VERSION_2020,
      'SketchUp 2021' => Sketchup::Model::VERSION_2021 #2021~2024
    }
  end

  def self.save_low_version_dialog
    # 获取版本列表字符串
    versions = self.supported_versions.keys.join('|')

    prompts = ["选择版本："]
    defaults = ["SketchUp 2018"] # 默认版本
    list = [ versions]
    title = "另存为低版本SKP文件"
    result = UI.inputbox(prompts, defaults, list, title)

    if result
      selected_version = result[0]
      version_number = self.supported_versions[selected_version]
      save_model_with_version(version_number, selected_version)
    else
      # UI.messagebox('未选择版本。')
    end
  end

  def self.save_model_with_version(version, selected_version)
    model = Sketchup.active_model
    filename = model.path
    if File.extname(filename).casecmp('.skp').zero?
      low_version_filename = filename.gsub('.skp', "_#{selected_version.gsub('SketchUp ', 'v')}.skp")
      model.save(low_version_filename, version)
      puts "文件已保存为 SketchUp #{selected_version} 版本 SKP 文件：#{low_version_filename}"
    else
      UI.messagebox('当前文件可能不是 SKP 文件，或者当前文件尚未保存过，如果是的话请先保存文件再来另存低版本。')
    end
  end

  # 添加菜单项
  UI.menu('File').add_item('另存为低版本SKP文件') do
    save_low_version_dialog
  end

  # 创建SketchUp扩展
  extension = SketchupExtension.new(extension_info[:name], 'SaveLowVersionSKP.rb')
  extension.creator = extension_info[:author]
  extension.version = extension_info[:version]
  extension.description = extension_info[:description]
  extension.copyright = extension_info[:copyright]
  
  # 注册扩展
  Sketchup.register_extension(extension, true)

end
